@@ -411,7 +411,9 @@ predict.mhingebst <- function(object, newdata=NULL, newy=NULL, mstop=NULL, type=
             all.folds <- balanced.folds(y, K)
         else all.folds <- cv.folds(length(y), K)
         fraction <- seq(mstop)
-        registerDoParallel(cores=n.cores)
+        #registerDoParallel(cores=n.cores)
+        cl <- eval(parse(text="parallel:::makeCluster(n.cores)"))
+        registerDoParallel(cl)
         i <- 1  ###needed to pass R CMD check with parallel code below
         residmat <- foreach(i=seq(K), .combine=cbind) %dopar% {
             omit <- all.folds[[i]]
@@ -420,7 +422,8 @@ predict.mhingebst <- function(object, newdata=NULL, newy=NULL, mstop=NULL, type=
             fit <- mhingebst(x[ - omit,,drop=FALSE  ], y[ - omit], cost = cost, family = family, learner = learner, ctrl = ctrl.cv, ...)
             predict.mhingebst(fit, newdata = x[omit,  ,drop=FALSE], newy=y[ omit], mstop = mstop, type=type)
         }
-	stopImplicitCluster()
+        eval(parse(text="parallel:::stopCluster(cl)"))
+	    #stopImplicitCluster()
         cv <- apply(residmat, 1, mean)
         cv.error <- sqrt(apply(residmat, 1, var)/K)
         object<-list(residmat=residmat, mstop = fraction, cv = cv, cv.error = cv.error)
